append_FOOOF: Combine EEG model data

Description Usage Arguments

View source: R/append_FOOOF.R

Description

This function is intended to be used after FOOOF_summaries() and is fairly inflexible The output from FOOOF_summaries() is a .csv file written to some data directory. If the FOOOF_summaries() function was implemented a number times, numerous .csv files will have been generated for each EEG condition, for example. This function appends (rbinds) those model data .csv files in a single directory. If the files are spread across directories, they will all need to be moved to one directory, and they should be the only files in that directory. All data will need to have the same variables (columns) for this function to work.

Usage

1
append_FOOOF(file_path, output_name, conds_pattern = ".._[0-9][0-9]")

Arguments

file_path

Path to directory of .csv files to rbind. Nothing else should be in this directory.

output_name

Name/name and path to output file.

conds_pattern

This function assumes a common naming convention among .csv files. For example, if all .csv files for the Eyes Closed condition at 32Hz contain "EC_32" in the file name, then the conds_pattern argument will take a regex is an input to parse the .csv file name and create a column for the output .csv, called condition, which extracts that regex. Defaults to "..0-9" which parses "XX##".


JasonDude16/FOOOFAnalysis documentation built on Dec. 18, 2021, 12:33 a.m.