read_EEG: Read EEG excel files

Description Usage Arguments

View source: R/read_EEG.R

Description

This function reads in EEG excel files where each sheet is a participant, each electrode is a row and each is the power expressed in Hz.

Usage

1
read_EEG(file, skip = 2:length(sheets), verbose = TRUE)

Arguments

file

Path to file to be read in.

skip

Numeric or character vector defining sheets to be skipped when reading. Defaults to 2:length(sheets).

verbose

Provides a summary of what was read in. Defaults to True.


JasonDude16/FOOOFAnalysis documentation built on Dec. 18, 2021, 12:33 a.m.