tidy_EEG: Tidy format EEG data

Description Usage Arguments

View source: R/tidy_EEG.R

Description

This function is intended to be used in conjunction with read_EEG(). In read_EEG(), the output is not in tidy format.This function formats the data in a way that is in alignment with tidy principles; namely, where each row is an observation and each column is a variable.

Usage

1
tidy_EEG(df, to_rownames = "channels", format = "to_FOOOF")

Arguments

df

EEG data sheet from read_EEG().

to_rownames

Assuming the data contain a column of electrode names, this column can be converted to rownames (recommended). Defaults to "channels".

format

Specifies the desired output, which is one of the following options: "avg_elec", "avg_freq", c("avg_elec", "avg_freq"), or "to_FOOOF", which will provide a list output that is conducive for performing FOOOF.


JasonDude16/FOOOFAnalysis documentation built on Dec. 18, 2021, 12:33 a.m.