This function reads in EEG excel files where each sheet is a participant, each electrode is a row and each is the power expressed in Hz.
1 |
file |
Path to file to be read in. |
skip |
Numeric or character vector defining sheets to be skipped when reading. Defaults to 2:length(sheets). |
verbose |
Provides a summary of what was read in. Defaults to True. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.