This function is intended to be used in conjunction with read_EEG().
In read_EEG(), the output is not in tidy format.This function formats the
data in a way that is in alignment with tidy principles; namely, where each
row is an observation and each column is a variable.
1 |
df |
EEG data sheet from |
to_rownames |
Assuming the data contain a column of electrode names, this column can be converted to rownames (recommended). Defaults to "channels". |
format |
Specifies the desired output, which is one of the following options: "avg_elec", "avg_freq", c("avg_elec", "avg_freq"), or "to_FOOOF", which will provide a list output that is conducive for performing FOOOF. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.